// Copyright 2017 The Johns Hopkins University Applied Physics Laboratory.
// Licensed under the MIT License. See LICENSE.txt in the project root for full license information.

#include <tclap/CmdLine.h>
#include <eopcc/las_io.hpp>
#include <eopcc/gdal_io.hpp>
#include <algorithm>





int main(int argc, char* argv[]) {
  try {
    TCLAP::CmdLine cmd("read-dem command line", ' ', "1.0");

    TCLAP::ValueArg<std::string> input_filename("i","input", "input dem", true,  "", "dem file");
    cmd.add(input_filename);
    cmd.parse(argc, argv);

    std::string input_file = input_filename.getValue();

    eopcc::GridModel<float> dem;
    dem = eopcc::LoadFromDEM(input_file);

    std::cout << dem.GetWKT() << std::endl;

    auto min_e = std::min_element(dem.grid.begin(), dem.grid.end());
    auto max_e = std::max_element(dem.grid.begin(), dem.grid.end());

    std::cout << dem.extent() << std::endl;
    std::cout << dem.spacingX() << ", " <<  dem.spacingY() << std::endl;
    std::cout << "Height: " << *min_e << " to " << *max_e << std::endl;

  } catch (std::exception& e) {
    std::cerr << "error: " << e.what() << std::endl;
    return EXIT_FAILURE;
  }

  return EXIT_SUCCESS;
}